@@ -71,8 +71,8 @@ sub descend
   $report = $main::report;
   $simnetwork = $main::simnetwork;
   
-  #open( my $OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-  open( my $TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!";  
+  #open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
+  open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!";  
   $tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
   say $tee "\n#Now in Sim::OPT::Descend.\n";
   
@@ -192,10 +192,10 @@ sub descend
   {   # IT CLEANS THE MIXED FILE AND SELECTS SOME COLUMNS, THEN COPIES THEM IN ANOTHER FILE
     my ( $repfile, $cleanmixed, $selectmixed ) = @_;
     say $tee "Cleaning results for case $countcaseplus, block $contblocksplus.";
-    open( my $MIXFILE, $repfile ) or die( "$!" ); say $tee "dump(\$repfile IN SUB cleanselect): " . dump($repfile); 
-    my @lines = <$MIXFILE>; 
-    close $MIXFILE;
-    open( my $CLEANMIXED, ">$cleanmixed" ) or die( "$!" );
+    open( MIXFILE, $repfile ) or die( "$!" ); say $tee "dump(\$repfile IN SUB cleanselect): " . dump($repfile); 
+    my @lines = <MIXFILE>; 
+    close MIXFILE;
+    open( CLEANMIXED, ">$cleanmixed" ) or die( "$!" );
     
     foreach my $line ( @lines )
     {
@@ -204,17 +204,17 @@ sub descend
       $line =~ s/°/\n/g;
       if ( ( $line ne "" ) and ( $line ne " " ) and ( $line ne "\n" ) )
       {
-        print $CLEANMIXED "$line";
+        print CLEANMIXED "$line";
       }
     }
-    close $CLEANMIXED;
+    close CLEANMIXED;
   
     # IT SELECTS SOME COLUMNS AND COPIES THEM IN ANOTHER FILE
-    open( $CLEANMIXED, $cleanmixed ) or die( "$!" );
-    my @lines = <$CLEANMIXED>; 
-    close $CLEANMIXED;
+    open( CLEANMIXED, $cleanmixed ) or die( "$!" );
+    my @lines = <CLEANMIXED>; 
+    close CLEANMIXED;
     
-    open( my $SELECTEDMIXED, ">$selectmixed" ) or die( "$!" );
+    open( SELECTEDMIXED, ">$selectmixed" ) or die( "$!" );
     foreach my $line (@lines)
     {
       if ( ( $line ne "" ) and ( $line ne " " ) and ( $line ne "\n" ) )
@@ -223,7 +223,7 @@ sub descend
         $elts[0] =~ /^(.*)_-(.*)/;
         my $touse = $1; 
         $touse =~ s/$mypath\///;
-        print $SELECTEDMIXED "$touse,";
+        print SELECTEDMIXED "$touse,";
         my $countout = 0;
         foreach my $elmref (@keepcolumns)
         {
@@ -233,20 +233,20 @@ sub descend
           {
             if ( Sim::OPT::odd($countin) )
             {
-              print $SELECTEDMIXED "$elts[$elm]";
+              print SELECTEDMIXED "$elts[$elm]";
             }
             else
             {
-              print $SELECTEDMIXED "$elm";
+              print SELECTEDMIXED "$elm";
             }
               
             if ( ( $countout < $#keepcolumns  ) or ( $countin < $#cols) )
             {
-              print  $SELECTEDMIXED ",";
+              print  SELECTEDMIXED ",";
             }
             else 
             {
-              print  $SELECTEDMIXED "\n";
+              print  SELECTEDMIXED "\n";
             }
             $countin++;
           }
@@ -254,7 +254,7 @@ sub descend
         }
       }
     }
-    close $SELECTEDMIXED;
+    close SELECTEDMIXED;
   }
 
     if ( not ( Sim::OPT::checkdone( $to, @rescontainer ) eq "yes" ) )
@@ -269,11 +269,11 @@ sub descend
   {  
     my ( $selectmixed, $weight ) = @_;
     say $tee "Scaling results for case $countcaseplus, block $contblocksplus.";
-    open( my $SELECTEDMIXED, $selectmixed ) or die( "$!" ); 
-    my @lines = <$SELECTEDMIXED>; 
-    close $SELECTEDMIXED;
+    open( SELECTEDMIXED, $selectmixed ) or die( "$!" ); 
+    my @lines = <SELECTEDMIXED>; 
+    close SELECTEDMIXED;
     my $counterline = 0;
-    open( my $WEIGHT, ">$weight" ) or die( "$!" );
+    open( WEIGHT, ">$weight" ) or die( "$!" );
     
     my @containerone;
     my @containernames;
@@ -322,26 +322,26 @@ sub descend
         push (@maxes, "NOTHING1");
       }
           
-      print $TOFILE "MAXES: " . Dumper(@maxes) . "\n";
-      print $TOFILE "DUMPCOLUMN: " . Dumper(@column) . "\n";
+      print TOFILE "MAXES: " . Dumper(@maxes) . "\n";
+      print TOFILE "DUMPCOLUMN: " . Dumper(@column) . "\n";
       
       foreach my $el (@column)
       {
         my $eltrans;
         if ( $maxes[$countcolm] != 0 )
         {
-          print $TOFILE "\$weights[\$countcolm]: $weights[$countcolm]\n";
+          print TOFILE "\$weights[\$countcolm]: $weights[$countcolm]\n";
           $eltrans = ( $el / $maxes[$countcolm] ) ;
         }
         else
         {
           $eltrans = "NOTHING2" ;
         }
-        push ( @{$containertwo[$countcolm]}, $eltrans) ; print $TOFILE "ELTRANS: $eltrans\n";
+        push ( @{$containertwo[$countcolm]}, $eltrans) ; print TOFILE "ELTRANS: $eltrans\n";
       }
       $countcolm++;
     } 
-    print $TOFILE "CONTAINERTWO " . Dumper(@containertwo) . "\n";
+    print TOFILE "CONTAINERTWO " . Dumper(@containertwo) . "\n";
         
     my $countline = 0;
     foreach my $line (@lines)
@@ -352,8 +352,8 @@ sub descend
       foreach $eltref (@containertwo)
       {
         my @col =  @{$eltref};
-        my $max = max(@col); print $TOFILE "MAX IN SUB weight: $max\n";
-        my $min = min(@col); print $TOFILE "MIN IN SUB weight: $min\n";
+        my $max = max(@col); print TOFILE "MAX IN SUB weight: $max\n";
+        my $min = min(@col); print TOFILE "MIN IN SUB weight: $min\n";
         my $floordistance = ($max - $min);
         my $el = $col[$countline];
         my $rescaledel;
@@ -378,21 +378,21 @@ sub descend
       my $counter = 0;
       foreach my $el (@elts)
       {    
-        print $WEIGHT "$el";
+        print WEIGHT "$el";
         if ($counter < $#elts)
         { 
-          print $WEIGHT ",";
+          print WEIGHT ",";
         }
         else
         {
-          print $WEIGHT "\n";
+          print WEIGHT "\n";
         }
         $containerthree[$counterline][$counter] = $el;
         $counter++;
       }
       $counterline++;
     }
-    close $WEIGHT;
+    close WEIGHT;
     
   }
   if ( not ( Sim::OPT::checkdone( $to, @rescontainer ) eq "yes" ) )
@@ -406,10 +406,10 @@ sub descend
   {
     my ( $weight, $weighttwo ) = @_;
     say $tee "Weighting results for case $countcaseplus, block $contblocksplus.";
-    open( my $WEIGHT, $weight ); 
-    my @lines = <$WEIGHT>;
-    close $WEIGHT;
-    open( my $WEIGHTTWO, ">$weighttwo" ); 
+    open( WEIGHT, $weight ); 
+    my @lines = <WEIGHT>;
+    close WEIGHT;
+    open( WEIGHTTWO, ">$weighttwo" ); 
     my $counterline;
     foreach my $line (@lines)
     {
@@ -425,9 +425,9 @@ sub descend
         my $newelt;
         if ($counterelt > ( $#elts - $numberels ))
         {
-          print $TOFILE "ELT: $elt\n";
+          print TOFILE "ELT: $elt\n";
           $newelt = ( $elt * abs($weights[$counterin]) ); 
-          print $TOFILE "ABS " . abs($weights[$counterin]) . "\n";
+          print TOFILE "ABS " . abs($weights[$counterin]) . "\n";
           $sum = ( $sum + $newelt ) ; 
           $counterin++;
         }
@@ -439,14 +439,14 @@ sub descend
       my $counter = 0;
       foreach my $elt (@elts)
       {    
-        print $WEIGHTTWO "$elt";
+        print WEIGHTTWO "$elt";
         if ($counter < $#elts)
         { 
-          print $WEIGHTTWO ",";
+          print WEIGHTTWO ",";
         }
         else
         {
-          print $WEIGHTTWO "\n";
+          print WEIGHTTWO "\n";
         }
         $counter++;
       }
@@ -466,10 +466,10 @@ sub descend
   {
     my ( $weighttwo, $sortmixed ) = @_;
     say $tee "Processing results for case $countcaseplus, block $contblocksplus.";
-    open( my $WEIGHTTWO, $weighttwo ) or die( "$!" ); 
-    open( my $SORTMIXED_, ">$sortmixed" ) or die( "$!" ); 
-    my @lines = <$WEIGHTTWO>;
-    close $WEIGHTTWO;
+    open( WEIGHTTWO, $weighttwo ) or die( "$!" ); 
+    open( SORTMIXED_, ">$sortmixed" ) or die( "$!" ); 
+    my @lines = <WEIGHTTWO>;
+    close WEIGHTTWO;
     
     my $count = 0;
     foreach ( @lines )
@@ -477,7 +477,7 @@ sub descend
       $_ = "$containernames[$count]," . "$_";
       $count++;
     }
-    say $TOFILE "TAKEOPTIMA--dump(\@lines): " . dump(@lines);
+    say TOFILE "TAKEOPTIMA--dump(\@lines): " . dump(@lines);
     
     my $line = $lines[0];
     my @eltstemp = split( /,/, $line );
@@ -490,7 +490,7 @@ sub descend
     {
       $line =~ s/^,//;
       $line =~ s/^\s+//;
-      print $SORTMIXED_ $line;
+      print SORTMIXED_ $line;
 
       if ( not ( Sim::OPT::checkdone( $to, @rescontainer ) eq "yes" ) )
       {
@@ -498,7 +498,7 @@ sub descend
       }
     }
     
-    #if ($numberelts > 0) { print $SORTMIXED_ `sort -t, -k$numberelts -n $weighttwo`; } 
+    #if ($numberelts > 0) { print SORTMIXED_ `sort -t, -k$numberelts -n $weighttwo`; } 
     
     #my @sorted = sort { $b->[1] <=> $a->[1] } @lines;
     
@@ -510,9 +510,9 @@ sub descend
     #  print $SORTMIXED "$elt";
     #}
 
-    #if ($numberelts > 0) { print $SORTMIXED_ `sort -n -k$numberelts,$numberelts -t , $weighttwo`; } ### ZZZ
+    #if ($numberelts > 0) { print SORTMIXED_ `sort -n -k$numberelts,$numberelts -t , $weighttwo`; } ### ZZZ
     
-    close $SORTMIXED_;
+    close SORTMIXED_;
   }
   sortmixed( $weighttwo, $sortmixed );
   
@@ -528,11 +528,11 @@ sub descend
     
     
     
-    open( my $SORTMIXED_, $sortmixed ) or die( "$!" );
-    my @lines = <$SORTMIXED_>;
-    close $SORTMIXED_;
+    open( SORTMIXED_, $sortmixed ) or die( "$!" );
+    my @lines = <SORTMIXED_>;
+    close SORTMIXED_;
     
-    my $winnerentry = $lines[0]; #ay $TOFILE "dump( IN SUB TAKEOPTIMA\$winnerentry): " . dump($winnerentry);
+    my $winnerentry = $lines[0]; #ay TOFILE "dump( IN SUB TAKEOPTIMA\$winnerentry): " . dump($winnerentry);
     chomp $winnerentry;
     
     my @winnerelms = split(/\s+|,/, $winnerentry);
@@ -550,7 +550,7 @@ sub descend
       $message = "$mypath\\attention.txt";
     }
     
-    open( my $MESSAGE, ">>$message");
+    open( MESSAGE, ">>$message");
     my $countelm = 0;
     foreach my $elm (@lines)
     {
@@ -562,13 +562,13 @@ sub descend
         {
           if ( $val ==  $winnerval )
           {
-            say $MESSAGE "Attention. At case $countcaseplus, block $contblocksplus. There is a tie between optimal cases. Besides case $winnerline, producing a compound objective function of $winnerval, there is the case $case producing the same objective function value. Case $winnerline has been used for the search procedures which follow.\n";
+            say MESSAGE "Attention. At case $countcaseplus, block $contblocksplus. There is a tie between optimal cases. Besides case $winnerline, producing a compound objective function of $winnerval, there is the case $case producing the same objective function value. Case $winnerline has been used for the search procedures which follow.\n";
           }
         }
       }
       $countelm++;
     }
-    close ($MESSAGE);
+    close (MESSAGE);
   say $tee "BEFORE PUSHING --->\@backvalues " . dump( @backvalues );
     my ( $copy, $newtarget );
     my ( @taken );
@@ -683,10 +683,10 @@ sub descend
       
       my $netinstnum = scalar( @morphcases );
       say $tee "#Net number of instances: $netinstnum." ;
-      open( my $RESPONSE , ">$mypath/response.txt" );
-      say $RESPONSE "#Optimal option for case  $countcaseplus: $newtarget";
+      open( RESPONSE , ">$mypath/response.txt" );
+      say RESPONSE "#Optimal option for case  $countcaseplus: $newtarget";
       
-      say $RESPONSE "#Net number of instances: $netinstnum." ;
+      say RESPONSE "#Net number of instances: $netinstnum." ;
         
       $countblock = 0;
       $countcase = $countcase++;
@@ -707,8 +707,8 @@ sub descend
     }
   }
   takeoptima( $sortmixed, \@uplift );
-  close $OUTFILE;
-  close $TOFILE;
+  close OUTFILE;
+  close TOFILE;
 }    # END SUB descend
 
 1;
