@@ -41,7 +41,7 @@ our @ISA = qw(Exporter); # our @adamkISA = qw(Exporter);
 #@EXPORT_OK   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 @EXPORT = qw( parcoord3d ); # our @EXPORT = qw( );
-$VERSION = '0.01'; 
+$VERSION = '0.01.3'; 
 $ABSTRACT = 'Sim::OPT::Parcoord3d is a program that can process the CSV data for a bi-dimensional parallel coordinate plot and output an Autolisp file for a 3D parallel coordinate plot.';
 
 #########################################################################################
@@ -122,7 +122,7 @@ sub parcoord3d
 		}
 		close CONVERTEDFILE;
 	
-		open (CONVERTEDFILE, "$convertedfile" );
+		open ( CONVERTEDFILE, "$convertedfile" );
 		@lines = <CONVERTEDFILE>;
 		close CONVERTEDFILE;
 	}
@@ -309,7 +309,7 @@ sub parcoord3d
 
 	sub printplotdata_pretreated
 	{
-		open (WRITEFILE_PRETREATED, ">$writefile_pretreated") or die;
+		open ( WRITEFILE_PRETREATED, ">$writefile_pretreated") or die;
 		print WRITEFILE_PRETREATED dump(@plotdata); #CONTROL!!!
 		close WRITEFILE_PREATREATED;
 	}
@@ -318,7 +318,7 @@ sub parcoord3d
 	sub solidify
 	{print "BEGUN\n";
 		my $swap = shift; my @plotdata = @$swap;
-		open (WRITEFILE, ">$writefile") or die;
+		open ( WRITEFILE, ">$writefile") or die;
 		my $countgroup = 0;
 		foreach my $e (@plotdata)
 		{
@@ -354,11 +354,11 @@ sub parcoord3d
 								{
 									$elms[0] = ( $elms[0] + ( $brushspacing * $counthit ) );
 								}
-								push ( @newnewbag, [ nlowmult(0.0001, $elms[0]), nlowmult(0.0001, $elms[1]), nlowmult(0.0001, $elms[2]), nlowmult(0.0001, $elms[3]) ]);
+								push ( @newnewbag, [ nlowmult($round, $elms[0]), nlowmult($round, $elms[1]), nlowmult($round, $elms[2]), nlowmult($round, $elms[3]) ]);
 							}
 							else
 							{
-								push(@newnewbag, [ nlowmult(0.0001, $elms[0]), nlowmult(0.0001, $elms[1]), nlowmult(0.0001, $elms[2]), nlowmult(0.0001, $elms[3]) ]);
+								push(@newnewbag, [ nlowmult($round, $elms[0]), nlowmult($round, $elms[1]), nlowmult($round, $elms[2]), nlowmult($round, $elms[3]) ]);
 							}
 						}
 					}	
@@ -443,7 +443,7 @@ sub parcoord3d
 					push( @newplotdataright, [ @newcoords ] );
 				}
 				
-				
+	
 				$countpar++;
 			}
 		
@@ -467,7 +467,7 @@ sub parcoord3d
 
 	sub writelisp
 	{
-		open(LISPFILE, ">$lispfile");
+		open( LISPFILE, ">$lispfile");
 		my $counter = 1;
 		foreach my $colour (@layercolours)
 		{
@@ -505,9 +505,9 @@ Sim::OPT::Parcoord3d is a program that can receive as input the data for a bi-di
 
 The objective function to be represented through colours in the parallel coordinate plot has to be put in the last (right) column in the CVS file.
 
-"Sim::OPT::Parcoord3d" can be called from !Sim::OPT! or directly from the command line (after issuing < re.pl > and < use Sim::OPT::Parcoord3d >) with the command < parcoord3d your_configuration_file.pl >.
+"Sim::OPT::Parcoord3d" can be called from Sim::OPT or directly from the command line (after issuing < re.pl > and < use Sim::OPT::Parcoord3d >) with the command < parcoord3d your_configuration_file.pl >.
 
-The variables to be specified in the configuration file are described in the comments in the "Sim::OPT" configuration file included in the "examples" folder in this distribution. 
+The variables to be specified in the configuration file are described in the comments in the "Sim::OPT" configuration file included in the "examples" folder in this distribution ("des.pl", for instance - then search for "Parcoord3d"). 
 
 
 =head2 EXPORT
@@ -524,7 +524,7 @@ Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 by Gian Luca Brunetti and Politecnico di Milano. This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2 or later.
+Copyright (C) 2015-2016 by Gian Luca Brunetti and Politecnico di Milano. This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2 or later.
 
 
 =cut
