@@ -88,7 +88,7 @@ sub sim    # This function launch the simulations in ESP-r
   $tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
   
   #open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-  open(my $TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!"; 
+  open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!"; 
   say $tee "\nNow in Sim::OPT::Sim.\n";
   
   %dowhat = %main::dowhat;
@@ -188,8 +188,8 @@ sub sim    # This function launch the simulations in ESP-r
     #my $prov =~ s/_-*$//;
     #if ( not ( $to ~~ @{ $simcases[$countcase] } ) )
     #{
-    #  push ( @simcases, $to ); say $TOFILE "simcases: " . dump(@simcases);
-    #  print $SIMLIST "$to\n";
+    #  push ( @simcases, $to ); say TOFILE "simcases: " . dump(@simcases);
+    #  print SIMLIST "$to\n";
     #}
     
     my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); 
@@ -230,29 +230,29 @@ sub sim    # This function launch the simulations in ESP-r
             my $resfile = "$simelt-$date_to_sim-$tooltype.res"; 
             my $flfile = "$simelt-$date_to_sim-$tooltype.fl"; 
 
-            #if ( fileno ($SIMLIST) )
+            #if ( fileno (SIMLIST) )
             #if (not (-e $simlist ) )
             #{
             #  if ( $countblock == 0 )
             #  {
-                open(my $SIMLIST, ">>$simlist") or die( "$!" );
+                open( SIMLIST, ">>$simlist") or die( "$!" );
             #  }
             #  else 
             #  {
-            #    open(my $SIMLIST, ">>$simlist") or die;
+            #    open( SIMLIST, ">>$simlist") or die;
             #  }
             #}
             
-            #if ( fileno ($SIMBLOCK) )
+            #if ( fileno (SIMBLOCK) )
             if (not (-e $simblock ) )
             {
               if ( $countblock == 0 )
               {
-                open(my $SIMBLOCK, ">>$simblock"); # or die;
+                open( SIMBLOCK, ">>$simblock"); # or die;
               }
               else 
               {
-                open(my $SIMBLOCK, ">>$simblock"); # or die;
+                open( SIMBLOCK, ">>$simblock"); # or die;
               }
             }
             
@@ -270,12 +270,12 @@ sub sim    # This function launch the simulations in ESP-r
             
             
             push ( @{ $simstruct[ $countcase ][ $countblock ][ $countinstance ][$counttool] }, $resfile );
-            print $SIMBLOCK "$resfile\n";
+            print SIMBLOCK "$resfile\n";
             
             if  ( ( ( not ( $resfile ~~ @simcases ) ) and ( not ( -e $resfile ) ) ) or ( not ( Sim::OPT::checkdone( $to, @rescontainer ) eq "yes" ) ) )
             {
               push ( @simcases, $resfile );
-              print $SIMLIST "$resfile\n";
+              print SIMLIST "$resfile\n";
                 
               unless ( ( $preventsim eq "y" ) or ( $dowhat{inactivatesim} eq "y" ) )
               {
@@ -310,7 +310,7 @@ XXX
                   {
                     print `$printthis`;
                   }
-                  print $TOFILE "   
+                  print TOFILE "   
       #Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance.\
       $printthis
       \n";
@@ -346,7 +346,7 @@ XXX
                   {
                     print `$printthis`;
                   }
-                  print $TOFILE "  
+                  print TOFILE "  
 $printthis
 ";
                 }          
@@ -410,13 +410,13 @@ $printthis
               }
             }
             
-            open (my $EPOLDPATH, "$epoldpath" ) or die( "$!" );
-            my @sourcecontents = <$EPOLDPATH>;
-            close $EPOLDPATH; 
+            open ( EPOLDPATH, "$epoldpath" ) or die( "$!" );
+            my @sourcecontents = <EPOLDPATH>;
+            close EPOLDPATH; 
             
             unless ( -e $epnewpath )
             {
-              open (my $EPNEWPATH, ">$epnewpath" ) or die( "$!" );
+              open ( EPNEWPATH, ">$epnewpath" ) or die( "$!" );
               foreach my $row ( @sourcecontents )
               {
                 foreach my $change ( @changes )
@@ -425,10 +425,10 @@ $printthis
                   my $target = $change->[1]; 
                   $row =~ s/$source/$target/ ; 
                 }
-                print $EPNEWPATH $row;
+                print EPNEWPATH $row;
 
               }  
-              close $EPNEWPATH;
+              close EPNEWPATH;
             }
             
             my $file_eplus = "$to/$file_eplus";  
@@ -453,11 +453,11 @@ $printthis
               {
                 if ( $countblock == 0 )
                 {
-                  open(my $SIMBLOCK, ">>$simblock"); # or die;
+                  open( SIMBLOCK, ">>$simblock"); # or die;
                 }
                 else 
                 {
-                  open(my $SIMBLOCK, ">>$simblock"); # or die;
+                  open( SIMBLOCK, ">>$simblock"); # or die;
                 }
               }
               
@@ -465,11 +465,11 @@ $printthis
               {
                 if ( $countblock == 0 )
                 {
-                  open(my $RETBLOCK, ">>$retblock"); # or die;
+                  open( RETBLOCK, ">>$retblock"); # or die;
                 }
                 else 
                 {
-                  open(my $RETBLOCK, ">>$retblock"); # or die;
+                  open( RETBLOCK, ">>$retblock"); # or die;
                 }
               }
             }
@@ -479,7 +479,7 @@ $printthis
             
             unless ( $dowhat{inactivatesim} eq "y" )
             {
-              print $SIMBLOCK "$resfile\n";
+              print SIMBLOCK "$resfile\n";
             }
             
             if ( ( not ( $resfile ~~ @retcases ) ) and ( not ( -e $resfile ) ) )
@@ -489,18 +489,18 @@ $printthis
               
               unless ( $dowhat{inactivatesim} eq "y" )
               {
-                print $SIMLIST "$resfile\n";
+                print SIMLIST "$resfile\n";
                 print RETLIST "$resfile\n";
               }
               
               unless ( ( $preventsim eq "y" ) or ( $dowhat{inactivatesim} eq "y" ) )
               {  
-                open (my $OLDFILEEPLUS, $epoldpath ) or die( "$!" );
-                my @oldlines = <$OLDFILEEPLUS>;
-                close $OLDFILEEPLUS;
+                open ( OLDFILEEPLUS, $epoldpath ) or die( "$!" );
+                my @oldlines = <OLDFILEEPLUS>;
+                close OLDFILEEPLUS;
                 unless ( -e $epnewpath )
                 {
-                  open (my $NEWFILEEPLUS, ">$epnewpath" ) or die( "$!" );
+                  open ( NEWFILEEPLUS, ">$epnewpath" ) or die( "$!" );
                   foreach my $line ( @oldlines )
                   {
                     foreach my $elt ( @changes )
@@ -509,9 +509,9 @@ $printthis
                       my $new = $elt->[1];
                       $line =~ s/$old/$new/;
                     }
-                    print $NEWFILEEPLUS $line;
+                    print NEWFILEEPLUS $line;
                   }
-                  close $NEWFILEEPLUS;
+                  close NEWFILEEPLUS;
                 }
                 
                 my $templaunch;
@@ -538,13 +538,13 @@ $printthis
                   }
                   unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
                   {
-                    print $TOFILE "cp -f $epnewpath $templaunch\n";
+                    print TOFILE "cp -f $epnewpath $templaunch\n";
                   }
                   else
                   {
-                    print $TOFILE "xcopy  /e /c /r /y $epnewpath $templaunch\n";
+                    print TOFILE "xcopy  /e /c /r /y $epnewpath $templaunch\n";
                   }
-                  print $TOFILE "runenergyplus $templaunch $epwfile\n";
+                  print TOFILE "runenergyplus $templaunch $epwfile\n";
                   
                   say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: using $epnewpath (actually $templaunch) to obtain $resfile. " ;                    
                 }
@@ -558,12 +558,12 @@ $printthis
     }  
     $countinstance++;
   }
-  close $SIMLIST;
-  close $SIMBLOCK;
+  close SIMLIST;
+  close SIMBLOCK;
   
   
   return ( \@simcases, \@simstruct );
-  close $TOFILE;
+  close TOFILE;
   close OUTFILE;
 }    # END SUB sim;      
 
